@@ -37,6 +37,8 @@
 #include "fieldtypes.h"
 #include <sstream>
 #include <iostream>
+#include <cassert>
+#include <climits>
 
 using lucene::search::Hits;
 using lucene::search::IndexSearcher;
@@ -435,7 +437,6 @@ CLuceneIndexReader::query(const Strigi::Query& q, int off, int max) {
     if (!checkReader()) {
         return results;
     }
-if (q.fields().size() > 0) cerr << q.fields()[0] << endl;
     // handle special commands
     if (q.fields().size() == 1 && q.fields()[0].empty()
             && q.term().string().substr(0, 14) == "strigispecial:") {
@@ -534,6 +535,10 @@ CLuceneIndexReader::getHits(const Strigi::Query& q,
             fullFields[i].assign(
                 "http://freedesktop.org/standards/xesam/1.0/core#"
                 + fields[i].substr(6));
+        } else if (fields[i].compare(0, 4, "nie:") == 0) {
+            fullFields[i].assign(
+                "http://www.semanticdesktop.org/ontologies/2007/01/19/nie#"
+                + fields[i].substr(4));
         } else {
             fullFields[i].assign(fields[i]);
         }
@@ -624,7 +629,7 @@ CLuceneIndexReader::documentId(const string& uri) {
     }
     _CLDELETE(docs);
 
-    if (id != -1 && reader->isDeleted(id)) {
+    if (id != -1 && reader->isDeleted((int32_t)id)) {
         id = -1;
     }
 
@@ -639,7 +644,7 @@ CLuceneIndexReader::mTime(int64_t docid) {
     if (docid < 0) return 0;
     if (!checkReader(true)) return 0;
     time_t mtime = 0;
-    Document *d = reader->document(docid);
+    Document *d = reader->document((int32_t)docid);
     if (d) {
         const TCHAR* v = d->get(Private::mtime());
         mtime = atoi(wchartoutf8( v ).c_str());
@@ -790,7 +795,7 @@ CLuceneIndexReader::keywords(const string& keywordmatch,
     set<wstring> s;
     wstring prefix = utf8toucs2(keywordmatch);
     const wchar_t* prefixtext = prefix.c_str();
-    uint32_t prefixLen = prefix.length();
+    string::size_type prefixLen = prefix.length();
     vector<string>::const_iterator i;
     Term* lastTerm = 0;
     for (i = fn.begin(); i != fn.end() && s.size() << max; ++i) {
