@@ -29,10 +29,14 @@
 #include <exiv2/exif.hpp>
 #include <exiv2/image.hpp>
 #include <exiv2/error.hpp>
-
-#include <cmath>
-
+#include <math.h>
 #ifdef _MSC_VER
+// at least MSVC2008 needs this define for defines like M_LN2
+#define _USE_MATH_DEFINES
+#include <cmath>
+#endif
+
+#if defined(__SUNPRO_CC) || defined(_MSC_VER)
 #define HUGE_VALF HUGE_VAL
 #endif
 
@@ -103,7 +107,6 @@ private:
     const RegisteredField* whiteBalanceField;
     const RegisteredField* meteringModeField;
     const RegisteredField* exposureField;
-    const RegisteredField* isoEquivField;
     const RegisteredField* jpegQualityField;
     const RegisteredField* userCommentField;
     const RegisteredField* jpegProcessField;
@@ -112,102 +115,80 @@ private:
     const RegisteredField* typeField;
 
 };
-/*
-const string commentFieldName("http://freedesktop.org/standards/xesam/1.0/core#contentComment");
-const string manufacturerFieldName("http://freedesktop.org/standards/xesam/1.0/core#cameraManufacturer");
-const string modelFieldName("http://freedesktop.org/standards/xesam/1.0/core#cameraModel");
-const string creationDateFieldName("http://freedesktop.org/standards/xesam/1.0/core#contentCreated");
-const string widthFieldName("http://freedesktop.org/standards/xesam/1.0/core#width");
-const string heightFieldName("http://freedesktop.org/standards/xesam/1.0/core#height");
-const string orientationFieldName("http://freedesktop.org/standards/xesam/1.0/core#orientation");
+
+#define NEXIF "http://www.semanticdesktop.org/ontologies/2007/05/10/nexif#"
+
+const string commentFieldName("http://www.semanticdesktop.org/ontologies/2007/01/19/nie#comment");
+const string manufacturerFieldName(NEXIF "make");
+const string modelFieldName(NEXIF "model");
+const string creationDateFieldName("http://www.semanticdesktop.org/ontologies/2007/01/19/nie#contentCreated");
+const string widthFieldName("http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#width");
+const string heightFieldName("http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#height");
+const string orientationFieldName(NEXIF "orientation");
 const string colorModeFieldName("http://freedesktop.org/standards/xesam/1.0/core#colorSpace");
-const string flashUsedFieldName("http://freedesktop.org/standards/xesam/1.0/core#flashUsed");
-const string focalLengthFieldName("http://freedesktop.org/standards/xesam/1.0/core#focalLength");
-const string _35mmEquivalentFieldName("http://freedesktop.org/standards/xesam/1.0/core#35mmEquivalent");
+const string flashUsedFieldName(NEXIF "flash");
+const string focalLengthFieldName(NEXIF "focalLength");
+const string _35mmEquivalentFieldName(NEXIF "focalLengthIn35mmFilm");
 const string ccdWidthFieldName("http://freedesktop.org/standards/xesam/1.0/core#ccdWidth");
-const string exposureTimeFieldName("http://freedesktop.org/standards/xesam/1.0/core#exposureTime");
-const string apertureFieldName("http://freedesktop.org/standards/xesam/1.0/core#aperture");
+const string exposureTimeFieldName(NEXIF "exposureTime");
+const string apertureFieldName(NEXIF "apertureValue");
 const string focusDistFieldName("http://freedesktop.org/standards/xesam/1.0/core#focusDistance");
-const string exposureBiasFieldName("http://freedesktop.org/standards/xesam/1.0/core#exposureBias");
-const string whiteBalanceFieldName("http://freedesktop.org/standards/xesam/1.0/core#whiteBalance");
-const string meteringModeFieldName("http://freedesktop.org/standards/xesam/1.0/core#meteringMode");
-const string exposureFieldName("http://freedesktop.org/standards/xesam/1.0/core#exposureProgram");
-const string isoEquivFieldName("http://freedesktop.org/standards/xesam/1.0/core#isoEquivalent");
+const string exposureBiasFieldName(NEXIF "exposureBiasValue");
+const string whiteBalanceFieldName(NEXIF "whiteBalance");
+const string meteringModeFieldName(NEXIF "meteringMode");
+const string exposureFieldName(NEXIF "exposureProgram");
 const string jpegQualityFieldName("http://freedesktop.org/standards/xesam/1.0/core#targetQuality");
-const string userCommentFieldName("http://freedesktop.org/standards/xesam/1.0/core#userComment");
+const string userCommentFieldName("http://www.semanticdesktop.org/ontologies/2007/01/19/nie#comment");
 const string jpegProcessFieldName("http://freedesktop.org/standards/xesam/1.0/core#compressionAlgorithm");
-const string thumbnailFieldName("content.thumbnail");
-*/
+const string thumbnailFieldName("http://strigi.sf.net/ontologies/homeless#contentThumbnail");
+const string ISOSpeedRatingsFieldName(NEXIF "isoSpeedRatings");
+
+#undef NEXIF
+
 /*
  Register the field names so that the StreamIndexer knows which analyzer
  provides what information.
 */
 void
 JpegEndAnalyzerFactory::registerFields(FieldRegister& r) {
-    commentField = r.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#contentComment");
+    commentField = r.registerField(commentFieldName);
     addField(commentField);
 
-    exifFields["Exif.Image.DateTime"] = r.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#contentCreated");
-    exifFields["Exif.Image.Make"] = r.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#cameraManufacturer");
-    exifFields["Exif.Image.Model"] = r.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#cameraModel");
-    exifFields["Exif.Photo.PixelXDimension"] = r.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#width");
-    exifFields["Exif.Photo.PixelYDimension"] = r.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#height");
-    exifFields["Exif.Image.Orientation"] = r.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#orientation");
-    exifFields["Exif.Photo.Flash"] = r.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#flashUsed");
-    exifFields["Exif.Photo.FocalLength"] = r.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#focalLength");
-    exifFields["Exif.Photo.FocalLengthIn35mmFilm"] = r.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#35mmEquivalent");
-    exifFields["Exif.Photo.ExposureTime"] = r.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#exposureTime");
-    exifFields["Exif.Photo.ApertureValue"] = r.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#aperture");
-    exifFields["Exif.Photo.ExposureBiasValue"] = r.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#exposureBias");
-    exifFields["Exif.Photo.WhiteBalance"] = r.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#whiteBalance");
-    exifFields["Exif.Photo.MeteringMode"] = r.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#meteringMode");
-    exifFields["Exif.Photo.ISOSpeedRatings"] = r.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#isoEquivalent");
-    map<string, const RegisteredField*>::const_iterator i = exifFields.begin();
+    exifFields["Exif.Image.DateTime"] = r.registerField(creationDateFieldName);
+    exifFields["Exif.Image.Make"] = r.registerField(manufacturerFieldName);
+    exifFields["Exif.Image.Model"] = r.registerField(modelFieldName);
+    exifFields["Exif.Photo.PixelXDimension"] = r.registerField(widthFieldName);
+    exifFields["Exif.Photo.PixelYDimension"] = r.registerField(heightFieldName);
+    exifFields["Exif.Image.Orientation"] = r.registerField(orientationFieldName);
+    exifFields["Exif.Photo.Flash"] = r.registerField(flashUsedFieldName);
+    exifFields["Exif.Photo.FocalLength"] = r.registerField(focalLengthFieldName);
+    exifFields["Exif.Photo.FocalLengthIn35mmFilm"] = r.registerField(_35mmEquivalentFieldName);
+    exifFields["Exif.Photo.ExposureTime"] = r.registerField(exposureTimeFieldName);
+    exifFields["Exif.Photo.ApertureValue"] = r.registerField(apertureFieldName);
+    exifFields["Exif.Photo.ExposureBiasValue"] = r.registerField(exposureBiasFieldName);
+    exifFields["Exif.Photo.WhiteBalance"] = r.registerField(whiteBalanceFieldName);
+    exifFields["Exif.Photo.MeteringMode"] = r.registerField(meteringModeFieldName);
+    exifFields["Exif.Photo.ISOSpeedRatings"] = r.registerField(ISOSpeedRatingsFieldName);
+
+map<string, const RegisteredField*>::const_iterator i = exifFields.begin();
     for (; i != exifFields.end(); ++i) {
         addField(i->second);
     }
 
-    colorModeField = r.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#colorSpace");
-    ccdWidthField = r.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#ccdWidth");
-    focusDistField = r.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#focusDistance");
-    exposureField = r.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#exposureProgram");
-    isoEquivField = r.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#isoEquivalent");
-    jpegQualityField = r.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#targetQuality");
-    userCommentField = r.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#userComment");
-    jpegProcessField = r.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#compressionAlgorithm");
-    thumbnailField = r.registerField(
-        "http://strigi.sf.net/ontologies/homeless#contentThumbnail");
+    colorModeField = r.registerField(colorModeFieldName);
+    ccdWidthField = r.registerField(ccdWidthFieldName);
+    focusDistField = r.registerField(focusDistFieldName);
+    exposureField = r.registerField(exposureFieldName);
+    jpegQualityField = r.registerField(jpegQualityFieldName);
+    userCommentField = r.registerField(userCommentFieldName);
+    jpegProcessField = r.registerField(jpegProcessFieldName);
+    thumbnailField = r.registerField(thumbnailFieldName);
     typeField = r.typeField;
 
     addField(colorModeField);
     addField(ccdWidthField);
     addField(focusDistField);
     addField(exposureField);
-    addField(isoEquivField);
     addField(jpegQualityField);
     addField(userCommentField);
     addField(jpegProcessField);
@@ -227,19 +208,17 @@ bool
 fnumberToApertureValue(string& fnumber) {
     // Convert the F number to the aperture value
     // return true if the value in fnumber is changed to ApertureValue
+    // F number = sqrt(pow(2, apex))
     char* end;
     double c = strtod(fnumber.c_str(), &end);
     if (c <= 0 || c == HUGE_VALF || *end == '\0') return false;
     double d = strtod(end + 1, &end);
     if (d <= 0 || d == HUGE_VALF) return false;
     c /= d;
-#ifdef _MSC_VER
-    double apex = log10(2.)/log10(c * c);
-    apex *= 65536;
+
+    // do not use log2() or round() here to be cross-platform
+    double apex = log(c*c) / M_LN2 * 65536;
     apex  = (apex < 0 ? ceil(apex - 0.5) : floor(apex + 0.5));
-#else
-    double apex = round(log2(c * c) * 65536);
-#endif
     std::ostringstream aperture;
     aperture << apex << "/65536";
     fnumber.assign(aperture.str());
@@ -256,7 +235,11 @@ JpegEndAnalyzer::analyze(AnalysisResult& ar, ::InputStream* in) {
     if (ar.depth() == 0) {
         try {
             // try to open the file directly: this is faster
-            img = Exiv2::ImageFactory::open(ar.path());
+            if (ar.path().compare(0, 5, "file:") == 0) {
+                img = Exiv2::ImageFactory::open(ar.path().substr(5));
+            } else {
+                img = Exiv2::ImageFactory::open(ar.path());
+            }
             img->readMetadata();
             ok = true;
         } catch (...) {
@@ -306,9 +289,9 @@ JpegEndAnalyzer::analyze(AnalysisResult& ar, ::InputStream* in) {
     const Exiv2::ExifData& exif = img->exifData();
     // if there's exif data, this is a photo, otherwise just an image
     if( ! exif.empty() ) {
-        ar.addValue(factory->typeField, "http://freedesktop.org/standards/xesam/1.0/core#Photo");
+        ar.addValue(factory->typeField, "http://www.semanticdesktop.org/ontologies/2007/05/10/nexif#Photo");
     } else {
-        ar.addValue(factory->typeField, "http://freedesktop.org/standards/xesam/1.0/core#Image");
+        ar.addValue(factory->typeField, "http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#RasterImage");
     }
 
     for (Exiv2::ExifData::const_iterator i = exif.begin(); i != exif.end();++i){
@@ -337,7 +320,7 @@ JpegEndAnalyzer::analyze(AnalysisResult& ar, ::InputStream* in) {
 #endif
     data = (const char*)thumbnail.pData_;
     if (data) {
-        StringInputStream thumbstream(data, thumbnail.size_, false);
+        StringInputStream thumbstream(data, (int32_t)thumbnail.size_, false);
         string thumbname("thumbnail");
 #if (EXIV2_TEST_VERSION(0,17,91))
         ar.indexChild(thumbname + thumb.extension(), ar.mTime(),
