@@ -30,11 +30,11 @@ using namespace Strigi;
 void
 TxtLineAnalyzerFactory::registerFields(FieldRegister& reg) {
     totalLinesField = reg.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#lineCount");
+        "http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#lineCount");
     totalWordsField = reg.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#wordCount");
+        "http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#wordCount");
     totalCharactersField = reg.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#characterCount");
+        "http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#characterCount");
     maxLineLengthField = reg.registerField(
         "http://strigi.sf.net/ontologies/homeless#maxLineLength");
 //TODO: this field should receive a proper name. What is meant is whether
@@ -99,11 +99,13 @@ TxtLineAnalyzer::endAnalysis(bool complete) {
         analysisResult->addValue(factory->totalWordsField, (int32_t)totalWords);
         analysisResult->addValue(factory->totalCharactersField, (int32_t)totalCharacters);
         analysisResult->addValue(factory->totalLinesField, (int32_t)totalLines);
+/* //FIXME: either get rid of this or replace with NIE equivalent
         analysisResult->addValue(factory->maxLineLengthField, (int32_t)maxLineLength);
         if (dos)
             analysisResult->addValue(factory->formatField, "DOS");
         else
             analysisResult->addValue(factory->formatField, "UNIX");
+*/
     }
     ready = true;
 }
