@@ -32,6 +32,7 @@
 #include "tarendanalyzer.h"
 #include "arendanalyzer.h"
 #include "zipexeendanalyzer.h"
+#include "odfendanalyzer.h"
 #include "oleendanalyzer.h"
 #include "rpmendanalyzer.h"
 #include "cpioendanalyzer.h"
@@ -44,11 +45,10 @@
 #include "mpegendanalyzer.h"
 #include "helperendanalyzer.h"
 #include "dataeventinputstream.h"
-#include "throughanalyzers/id3v2throughanalyzer.h"
+#include "endanalyzers/id3endanalyzer.h"
 #include "throughanalyzers/oggthroughanalyzer.h"
+#include "flacendanalyzer.h"
 #include "eventanalyzers/digesteventanalyzer.h"
-#include "lineanalyzers/odfmimetypelineanalyzer.h"
-#include "saxanalyzers/odfsaxanalyzer.h"
 #include "analysisresult.h"
 #include "indexwriter.h"
 #include "analyzerconfiguration.h"
@@ -236,7 +236,7 @@ StreamAnalyzerPrivate::initializeLineFactories() {
     for (i = plugins.begin(); i != plugins.end(); ++i) {
         addFactory(*i);
     }
-    addFactory(new OdfMimeTypeLineAnalyzerFactory());
+//    addFactory(new OdfMimeTypeLineAnalyzerFactory());
     addFactory(new M3uLineAnalyzerFactory());
 }
 void
@@ -258,7 +258,6 @@ StreamAnalyzerPrivate::initializeThroughFactories() {
     for (i = plugins.begin(); i != plugins.end(); ++i) {
         addFactory(*i);
     }
-    addFactory(new ID3V2ThroughAnalyzerFactory());
     addFactory(new OggThroughAnalyzerFactory());
     addFactory(new EventThroughAnalyzerFactory(saxfactories, linefactories,
         eventfactories));
@@ -317,13 +316,15 @@ StreamAnalyzerPrivate::initializeEndFactories() {
     addFactory(new ArEndAnalyzerFactory());
     addFactory(new MailEndAnalyzerFactory());
     addFactory(new MpegEndAnalyzerFactory());
+    addFactory(new OdfEndAnalyzerFactory());
     addFactory(new ZipEndAnalyzerFactory());
     addFactory(new ZipExeEndAnalyzerFactory());
     addFactory(new RpmEndAnalyzerFactory());
     addFactory(new CpioEndAnalyzerFactory());
     addFactory(new PngEndAnalyzerFactory());
     addFactory(new BmpEndAnalyzerFactory());
-    addFactory(new OdfSaxAnalyzerFactory());
+    addFactory(new FlacEndAnalyzerFactory());
+    addFactory(new ID3EndAnalyzerFactory());
     addFactory(new PdfEndAnalyzerFactory());
     addFactory(new SdfEndAnalyzerFactory());
     addFactory(new LzmaEndAnalyzerFactory());
@@ -392,6 +393,9 @@ StreamAnalyzerPrivate::analyze(AnalysisResult& idx, StreamBase<char>* input) {
             && ts != tIter->end(); ++ts) {
         (*ts)->setIndexable(&idx);
         input = (*ts)->connectInputStream(input);
+        if (input && input->position() != 0) {
+            cerr << "Analyzer " << (*ts)->name() << " has left the stream in a bad state." << endl;
+        }
     }
 
     // reread the header so we can use it for the endanalyzers
@@ -408,16 +412,17 @@ StreamAnalyzerPrivate::analyze(AnalysisResult& idx, StreamBase<char>* input) {
         headersize = -1;
         finished = true;
     }
-    int es = 0;
-    int itersize = eIter->size();
+    size_t es = 0;
+    size_t itersize = eIter->size();
     while (!finished && es != itersize) {
         StreamEndAnalyzer* sea = (*eIter)[es];
         if (sea->checkHeader(header, headersize)) {
             idx.setEndAnalyzer(sea);
             char ar = sea->analyze(idx, input);
             if (ar) {
-                idx.addValue(errorfield, sea->name() + string(": ")
-                    + sea->error());
+// FIXME: find either a NIE-compliant way to report errors or use some API for this
+//                idx.addValue(errorfield, sea->name() + string(": ")
+//                    + sea->error());
                 if (!idx.config().indexMore()) {
                     removeIndexable(idx.depth());
                     return -1;
