@@ -35,15 +35,15 @@ using namespace Strigi;
 void
 IcoThroughAnalyzerFactory::registerFields(FieldRegister& reg) {
     widthField = reg.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#width");
+        "http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#width");
     heightField = reg.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#height");
+        "http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#height");
     numberField = reg.registerField(
         "http://strigi.sf.net/ontologies/homeless#documentImageCount");
     bitsPerPixelField = reg.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#pixelDataBitDepth");
+        "http://www.semanticdesktop.org/ontologies/nfo#colorDepth");
     colorCountField = reg.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#colorCount");
+        "http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#colorCount");
 
     addField(widthField);
     addField(heightField);
@@ -141,7 +141,8 @@ IcoThroughAnalyzer::connectInputStream(InputStream* in) {
     /*uint32_t icoe_imageoffset =*/ readLittleEndianUInt32(c);
 
     // read the data on the 1st icon
-    analysisResult->addValue( factory->numberField, ico_count );
+    //FIXME: either get rid of this or replace with NIE equivalent
+    //analysisResult->addValue( factory->numberField, ico_count );
 
     analysisResult->addValue( factory->widthField, icoe_width );
     analysisResult->addValue( factory->heightField, icoe_height );
