@@ -40,13 +40,13 @@ using namespace Strigi;
 void
 RgbThroughAnalyzerFactory::registerFields(FieldRegister& reg) {
     widthField = reg.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#width");
+        "http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#width");
     heightField = reg.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#height");
+        "http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#height");
     bitDepthField = reg.registerField(
-        "http://freedesktop.org/standards/xesam/1.0/core#pixelDataBitDepth");
+        "http://www.semanticdesktop.org/ontologies/nfo#colorDepth");
     imageNameField = reg.registerField(
-        "http://strigi.sf.net/ontologies/homeless#documentImageName");
+        "http://www.semanticdesktop.org/ontologies/2007/01/19/nie#title");
     sharedRowsField = reg.registerField(
         "http://strigi.sf.net/ontologies/homeless#documentImageSharedRows");
     colorModeField = reg.registerField(
@@ -81,8 +81,10 @@ RgbThroughAnalyzer::connectInputStream(InputStream* in) {
     const int64_t pos = in->position();
     in->reset(pos);   // rewind to the start of the stream
     if (512 != in->read(c, 512, 512)) {
+       in->reset(pos);
        return in;
     }
+    in->reset(pos);
     magic = readBigEndianUInt16(c);
     if (magic != 474) {
         return in;
@@ -116,6 +118,7 @@ RgbThroughAnalyzer::connectInputStream(InputStream* in) {
     if (imagename[0] != '\0') {
         analysisResult->addValue( factory->imageNameField, imagename);
     }
+    /* //FIXME: either get rid of this or replace with NIE equivalent
     if (zsize == 1)
         analysisResult->addValue( factory->colorModeField, "Grayscale");
     else if (zsize == 2)
@@ -131,6 +134,7 @@ RgbThroughAnalyzer::connectInputStream(InputStream* in) {
         analysisResult->addValue( factory->compressionField,
                                   string ("Runlength Encoded"));
     }
+    */
     return in;
 }
 
