@@ -265,7 +265,7 @@ ArchiveReader::ArchiveReaderPrivate::positionedProvider(const string& url) {
                            e.filename.length()) == 0) {
                 nextstream = true;
                 // skip the number of entries that are matched
-                uint end = *i + e.filename.length();
+                size_t end = *i + e.filename.length();
                 do {
                     ++i;
                 } while (i != partpos.rend() && *i < end);
@@ -419,7 +419,7 @@ ArchiveReader::isArchive(const std::string& url) {
     if (p->localStat(url, e) != 0) {
         return false;
     }
-    return e.type & (EntryInfo::File | EntryInfo::Dir);
+    return ((e.type & (EntryInfo::File | EntryInfo::Dir)) != 0);
 }
 std::vector<EntryInfo>
 convert(const ArchiveEntryCache::SubEntry* entry) {
