@@ -25,15 +25,11 @@ using namespace Strigi;
 
 int
 GZipInputStreamTest(int argc, char* argv[]) {
-    if (argc < 2) return 0;
+    if (argc < 2) return 1;
     VERIFY(chdir(argv[1]) == 0);
 
     founderrors = 0;
-    for (int i=0; i<ninputstreamtests; ++i) {
-        FileInputStream file("a.gz");
-        GZipInputStream gzip(&file);
-        charinputstreamtests[i](&gzip);
-    }
+    TESTONFILE(GZipInputStream, "a.gz");
     return founderrors;
 }
 
