@@ -25,15 +25,11 @@ using namespace Strigi;
 
 int
 MailInputStreamTest(int argc, char* argv[]) {
-    if (argc < 2) return 0;
+    if (argc < 2) return 1;
     founderrors = 0;
     VERIFY(chdir(argv[1]) == 0);
 
-    for (int i=0; i<nstreamprovidertests; ++i) {
-        FileInputStream file("mail");
-        MailInputStream mail(&file);
-        streamprovidertests[i](&mail);
-    }
+    TESTONARCHIVE(MailInputStream, "mail");
     return founderrors;
 }
 
