@@ -18,7 +18,6 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#include "../fileinputstream.h"
 #include "../zipinputstream.h"
 #include "inputstreamtests.h"
 
@@ -30,11 +29,19 @@ ZipInputStreamTest(int argc, char* argv[]) {
     founderrors = 0;
     VERIFY(chdir(argv[1]) == 0);
 
-    for (int i=0; i<nstreamprovidertests; ++i) {
-        FileInputStream file("a.zip");
-        ZipInputStream zip(&file);
-        streamprovidertests[i](&zip);
-    }
+    TESTONARCHIVE(ZipInputStream, "a.zip");
+
+    // should have at least one stream
+    InputStream* file = new SkippingFileInputStream("a.zip");
+    const char* data;
+    file->read(data, 500, 500);
+    file->reset(0);
+    VERIFY(file->status() == Ok);
+    ZipInputStream *zip = new ZipInputStream(file);
+    InputStream* i = zip->nextEntry();
+    VERIFY(i);
+    delete zip;
+    delete file;
 
     return founderrors;
 }
